@@ -506,6 +506,14 @@ failed to upload.</source>
         <source>Cancel</source>
         <translation>Cancel·la</translation>
     </message>
+    <message>
+        <source>end-to-end encryption</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>TextLabel</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>DaemonManager</name>
@@ -3142,6 +3150,10 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Delete file sync error failed</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TwoFactorDialog</name>
