@@ -505,6 +505,14 @@ failed to upload.</source>
         <source>Cancel</source>
         <translation>Відміна</translation>
     </message>
+    <message>
+        <source>end-to-end encryption</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>TextLabel</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>DaemonManager</name>
@@ -3141,6 +3149,10 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Delete file sync error failed</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TwoFactorDialog</name>
