@@ -31,6 +31,7 @@ enum CommandType : uint32_t {
     DoUnlockFile = 5,
     DoShowFileHistory = 6,
     DoShowFileLockedBy = 7,
+    DoGetUploadLink = 8,
 };
 
 struct mach_msg_command_send_t {
@@ -258,6 +259,11 @@ static void handleGetWatchSet(mach_msg_command_rcv_t* msg) {
                                   Qt::QueuedConnection,
                                   Q_ARG(QString, msg->body));
         break;
+    case DoGetUploadLink:
+        QMetaObject::invokeMethod(finder_sync_host_.get(), "doGetUploadLink",
+                                  Qt::QueuedConnection,
+                                  Q_ARG(QString, msg->body));
+        break;
     default:
         qWarning("[FinderSync] received unknown command %u", msg->command);
         break;
