@@ -312,7 +312,7 @@ void SeafileApplet::onDaemonStarted()
     AccountInfoService::instance()->start();
     SeafileAppletRpcServer::instance()->start();
 
-    account_mgr_->updateServerInfo();
+    account_mgr_->updateServerInfoForAllAccounts();
 
     //
     // start ui part
@@ -339,9 +339,7 @@ void SeafileApplet::onDaemonStarted()
                 settingsManager()->setComputerName(computer_name);
             if (!username.isEmpty() && !token.isEmpty() && !url.isEmpty()) {
                 Account account(url, username, token);
-                if (account_mgr_->saveAccount(account) < 0) {
-                    errorAndExit(tr("failed to add default account"));
-                }
+                account_mgr_->setCurrentAccount(account);
                 break;
             }
 
