@@ -1,4 +1,5 @@
 #include <windows.h>
+#include <shellapi.h>
 #include <wincrypt.h>
 #include <glib.h>
 
@@ -305,6 +306,30 @@ std::string getLocalPipeName(const char *pipe_name)
     }
 }
 
+// Qt's QProcess function cannot invoke programs that require administrator privileges,
+// so we need windows api funtion to invoke the program that require adminstrator privileges.
+DWORD runShellAsAdministrator(LPCSTR cmd, LPCSTR arg, int n_show)
+{
+    SHELLEXECUTEINFO shell_exec_info = {0};
+    shell_exec_info.cbSize = sizeof(SHELLEXECUTEINFO);
+    shell_exec_info.fMask = SEE_MASK_NOCLOSEPROCESS;
+    shell_exec_info.hwnd = NULL;
+    shell_exec_info.lpVerb = "runas";
+    shell_exec_info.lpFile = cmd;
+    shell_exec_info.lpParameters = arg;
+    shell_exec_info.lpDirectory = NULL;
+    shell_exec_info.nShow = n_show;
+    shell_exec_info.hInstApp = NULL;
+
+    BOOL ret = ShellExecuteEx(&shell_exec_info);
+    WaitForSingleObject(shell_exec_info.hProcess, INFINITE);
+
+    DWORD exit_code=0;
+    GetExitCodeProcess(shell_exec_info.hProcess, &exit_code);
+    CloseHandle(shell_exec_info.hProcess);
+    return exit_code;
+}
+
 
 } // namespace win
 
